# Generated by Django 3.2.11 on 2022-02-28 17:32

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_csf", "0005_auto_20220225_2142"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicallpcsf",
            name="csf_culture",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("awaiting_results", "Awaiting results"),
                    ("not_done", "Not done"),
                    ("N/A", "Not applicable"),
                ],
                default="awaiting_results",
                help_text="Complete after getting the results.",
                max_length=18,
                verbose_name="CSF Result: Other organism (non-Cryptococcus)",
            ),
        ),
        migrations.AlterField(
            model_name="historicallpcsf",
            name="csf_positive",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("awaiting_results", "Awaiting results"),
                ],
                default="awaiting_results",
                max_length=18,
                verbose_name="CSF positive for cryptococcal meningitis?",
            ),
        ),
        migrations.AlterField(
            model_name="lpcsf",
            name="csf_culture",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("awaiting_results", "Awaiting results"),
                    ("not_done", "Not done"),
                    ("N/A", "Not applicable"),
                ],
                default="awaiting_results",
                help_text="Complete after getting the results.",
                max_length=18,
                verbose_name="CSF Result: Other organism (non-Cryptococcus)",
            ),
        ),
        migrations.AlterField(
            model_name="lpcsf",
            name="csf_positive",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("awaiting_results", "Awaiting results"),
                ],
                default="awaiting_results",
                max_length=18,
                verbose_name="CSF positive for cryptococcal meningitis?",
            ),
        ),
    ]
